==> owncloud_8.0.16.orig.tar.gz: owncloud/lib/l10n/nb_NO.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Kan ikke skrive i \"config\"-mappen!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Dette kan vanligvis ordnes ved å gi web-serveren skrivetilgang til config-mappen",
    "See %s" : "Se %s",
    "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "Dette kan vanligvis ordnes ved %så gi web-serveren skrivetilgang til config-mappen%s.",
    "Sample configuration detected" : "Eksempelkonfigurasjon oppdaget",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Det ble oppdaget at eksempelkonfigurasjonen er blitt kopiert. Dette kan ødelegge installasjonen din og støttes ikke. Les dokumentasjonen før du gjør endringer i config.php",
    "PHP %s or higher is required." : "PHP %s eller nyere kreves.",
    "PHP with a version lower than %s is required." : "PHP med en versjon lavere enn %s kreves.",
    "Following databases are supported: %s" : "Følgende databaser støttes: %s",
    "The command line tool %s could not be found" : "Kommandolinjeverktøyet %s ble ikke funnet",
    "The library %s is not available." : "Biblioteket %s er ikke tilgjengelig.",
    "Library %s with a version higher than %s is required - available version %s." : "Bibliotek %s med en versjon høyere enn %s kreves - tilgjengelig versjon %s.",
    "Library %s with a version lower than %s is required - available version %s." : "Bibliotek %s med en versjon lavere nn %s kreves - tilgjengelig version %s.",
    "Following platforms are supported: %s" : "Følgende plattformer støttes: %s",
    "ownCloud %s or higher is required." : "ownCloud %s eller høyere kreves.",
    "ownCloud with a version lower than %s is required." : "ownCloud med en versjon lavere enn %s kreves.",
    "Help" : "Hjelp",
    "Personal" : "Personlig",
    "Settings" : "Innstillinger",
    "Users" : "Brukere",
    "Admin" : "Admin",
    "Recommended" : "Anbefalt",
    "App \\\"%s\\\" can't be installed because it is not compatible with this version of ownCloud." : "App \\\"%s\\\" kan ikke installeres fordi den ikke er kompatibel med denne versjoen av ownCloud.",
    "App \\\"%s\\\" cannot be installed because the following dependencies are not fulfilled: %s" : "App \\\"%s\\\" kan ikke installeres fordi følgende avhengigheter ikke er tilfredsstilt: %s",
    "No app name specified" : "Intet app-navn spesifisert",
    "Unknown filetype" : "Ukjent filtype",
    "Invalid image" : "Ugyldig bilde",
    "today" : "i dag",
    "yesterday" : "i går",
    "_%n day ago_::_%n days ago_" : ["%n dag siden","%n dager siden"],
    "last month" : "forrige måned",
    "_%n month ago_::_%n months ago_" : ["for %n måned siden","for %n måneder siden"],
    "last year" : "forrige år",
    "_%n year ago_::_%n years ago_" : ["%n år siden","%n år siden"],
    "_%n hour ago_::_%n hours ago_" : ["for %n time siden","for %n timer siden"],
    "_%n minute ago_::_%n minutes ago_" : ["for %n minutt siden","for %n minutter siden"],
    "seconds ago" : "for få sekunder siden",
    "Database Error" : "Databasefeil",
    "Please contact your system administrator." : "Vennligst kontakt systemadministratoren.",
    "web services under your control" : "webtjenester som du kontrollerer",
    "App directory already exists" : "App-mappe finnes allerede",
    "Can't create app folder. Please fix permissions. %s" : "Kan ikke opprette app-mappe.  Vennligst ordne opp i tillatelser. %s",
    "No source specified when installing app" : "Ingen kilde spesifisert ved installering av app",
    "No href specified when installing app from http" : "Ingen href spesifisert ved installering av app fra http",
    "No path specified when installing app from local file" : "Ingen sti spesifisert ved installering av app fra lokal fil",
    "Archives of type %s are not supported" : "Arkiver av type %s støttes ikke",
    "Failed to open archive when installing app" : "Klarte ikke å åpne arkiv ved installering av app",
    "App does not provide an info.xml file" : "App-en inneholder ikke filen info.xml",
    "App can't be installed because of not allowed code in the App" : "App kan ikke installeres på grunn av ulovlig kode i appen.",
    "App can't be installed because it is not compatible with this version of ownCloud" : "App kan ikke installeres fordi den ikke er kompatibel med denne versjonen av ownCloud",
    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "App kan ikke installeres fordi den inneholder tag <shipped>true</shipped> som ikke er tillatt for apper som ikke leveres med systemet",
    "App can't be installed because the version in info.xml/version is not the same as the version reported from the app store" : "App kan ikke installeres fordi versjonen i info.xml/version ikke er den samme som versjonen som rapporteres fra app-butikken",
    "Application is not enabled" : "Applikasjon er ikke påslått",
    "Authentication error" : "Autentikasjonsfeil",
    "Token expired. Please reload page." : "Symbol utløpt. Vennligst last inn siden på nytt.",
    "Unknown user" : "Ukjent bruker",
    "%s enter the database username." : "%s legg inn brukernavn for databasen.",
    "%s enter the database name." : "%s legg inn navnet på databasen.",
    "%s you may not use dots in the database name" : "%s du kan ikke bruke punktum i databasenavnet",
    "MS SQL username and/or password not valid: %s" : "MS SQL-brukernavn og/eller passord ikke gyldig: %s",
    "You need to enter either an existing account or the administrator." : "Du må legge inn enten en eksisterende konto eller administratoren.",
    "MySQL/MariaDB username and/or password not valid" : "MySQL/MariaDB-brukernavn og/eller -passord ikke gyldig",
    "DB Error: \"%s\"" : "Databasefeil: \"%s\"",
    "Offending command was: \"%s\"" : "Kommandoen som feilet: \"%s\"",
    "MySQL/MariaDB user '%s'@'localhost' exists already." : "MySQL/MariaDB-bruker '%s'@'localhost' finnes allerede.",
    "Drop this user from MySQL/MariaDB" : "Fjern denne brukeren fra MySQL/MariaDB",
    "MySQL/MariaDB user '%s'@'%%' already exists" : "MySQL/MariaDB-bruker '%s'@'%%' finnes allerede",
    "Drop this user from MySQL/MariaDB." : "Fjern denne brukeren fra MySQL/MariaDB.",
    "Oracle connection could not be established" : "Klarte ikke å etablere forbindelse til Oracle",
    "Oracle username and/or password not valid" : "Oracle-brukernavn og/eller passord er ikke gyldig",
    "Offending command was: \"%s\", name: %s, password: %s" : "Kommando som feilet: \"%s\", navn: %s, passord: %s",
    "PostgreSQL username and/or password not valid" : "PostgreSQL-brukernavn og/eller passord er ikke gyldig",
    "Set an admin username." : "Sett et admin-brukernavn.",
    "Set an admin password." : "Sett et admin-passord.",
    "Can't create or write into the data directory %s" : "Kan ikke opprette eller skrive i datamappen %s",
    "%s shared »%s« with you" : "%s delte »%s« med deg",
    "Sharing %s failed, because the backend does not allow shares from type %i" : "Deling av %s feilet, fordi serveren ikke tillater delinger fra type %i",
    "Sharing %s failed, because the file does not exist" : "Deling av %s feilet, fordi filen ikke eksisterer",
    "You are not allowed to share %s" : "Du har ikke lov til å dele %s",
    "Sharing %s failed, because the user %s is the item owner" : "Deling av %s feilet, fordi brukeren %s er eier av elementet",
    "Sharing %s failed, because the user %s does not exist" : "Deling av %s feilet, fordi brukeren %s ikke finnes",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Deling av %s feilet, fordi brukeren %s ikke er medlem av noen grupper som %s er medlem av",
    "Sharing %s failed, because this item is already shared with %s" : "Deling av %s feilet, fordi dette elementet allerede er delt med %s",
    "Sharing %s failed, because the group %s does not exist" : "Deling av %s feilet, fordi gruppen %s ikke finnes",
    "Sharing %s failed, because %s is not a member of the group %s" : "Deling av %s feilet, fordi %s ikke er medlem av gruppen %s",
    "You need to provide a password to create a public link, only protected links are allowed" : "Du må oppgi et passord for å lage en offentlig lenke. Bare beskyttede lenker er tillatt",
    "Sharing %s failed, because sharing with links is not allowed" : "Deling av %s feilet, fordi deling med lenker ikke er tillatt",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Deling %s feilet, fant ikke %s, kanskje servern er utilgjengelig for øyeblikket.",
    "Share type %s is not valid for %s" : "Delingstype %s er ikke gyldig for %s",
    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "Setting av tillatelser for %s feilet, fordi tillatelsene gikk ut over tillatelsene som er gitt til %s",
    "Setting permissions for %s failed, because the item was not found" : "Setting av tillatelser for %s feilet, fordi elementet ikke ble funnet",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Kan ikke sette utøpsdato. Delinger kan ikke utløpe senere enn %s etter at de har blitt delt",
    "Cannot set expiration date. Expiration date is in the past" : "Kan ikke sette utløpsdato. Utløpsdato er tilbake i tid",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Delings-server %s må implementere grensesnittet OCP\\Share_Backend",
    "Sharing backend %s not found" : "Delings-server %s ikke funnet",
    "Sharing backend for %s not found" : "Delings-server for %s ikke funnet",
    "Sharing %s failed, because the user %s is the original sharer" : "Deling av %s feilet, fordi brukeren %s er den opprinnelige eieren",
    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Deling av %s feilet, fordi tillatelsene går utover tillatelsene som er gitt til %s",
    "Sharing %s failed, because resharing is not allowed" : "Deling av %s feilet, fordi videre-deling ikke er tillatt",
    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Deling av %s feilet, fordi delings-serveren for %s ikke kunne finne kilden",
    "Sharing %s failed, because the file could not be found in the file cache" : "Deling av %s feilet, fordi filen ikke ble funnet i fil-mellomlageret",
    "Could not find category \"%s\"" : "Kunne ikke finne kategori \"%s\"",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-\"" : "Bare disse tegnene tillates i et brukernavn: \"a-z\", \"A-Z\", \"0-9\" og \"_.@-\"",
    "A valid username must be provided" : "Oppgi et gyldig brukernavn",
    "A valid password must be provided" : "Oppgi et gyldig passord",
    "The username is already being used" : "Brukernavnet er allerede i bruk",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Ingen databasedrivere (sqlite, mysql, or postgresql) installert.",
    "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Tillatelser kan vanligvis ordnes ved %så gi web-serveren skrivetilgang til rotmappen%s.",
    "Cannot write into \"config\" directory" : "Kan ikke skrive i \"config\"-mappen",
    "Cannot write into \"apps\" directory" : "Kan ikke skrive i \"apps\"-mappen",
    "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Dette kan vanligvis ordnes ved %så gi web-serveren skrivetilgang til apps-mappen%s eller ved å deaktivere app-butikken i config-filen.",
    "Cannot create \"data\" directory (%s)" : "Kan ikke opprette \"data\"-mappen (%s)",
    "This can usually be fixed by <a href=\"%s\" target=\"_blank\">giving the webserver write access to the root directory</a>." : "Dette kan vanligvis ordnes ved <a href=\"%s\" target=\"_blank\">gi web-serveren skrivetilgang til rotmappen</a>.",
    "Setting locale to %s failed" : "Setting av nasjonale innstillinger til %s feilet.",
    "Please install one of these locales on your system and restart your webserver." : "Vennligst installer en av disse nasjonale innstillingene på systemet ditt og start webserveren på nytt.",
    "Please ask your server administrator to install the module." : "Be server-administratoren om å installere modulen.",
    "PHP module %s not installed." : "PHP-modul %s er ikke installert.",
    "Please ask your server administrator to update PHP to the latest version. Your PHP version is no longer supported by ownCloud and the PHP community." : "Be server-administratoren om å oppdatere PHP til nyeste versjon. PHP-versjonen du bruker støttes ikke lenger av ownCloud og PHP-fellesskapet.",
    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "Det ser ut for at PHP er satt opp til å fjerne innebygde doc blocks. Dette gjør at flere av kjerneapplikasjonene blir utilgjengelige.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Dette forårsakes sannsynligvis av en bufrer/akselerator, som f.eks. Zend OPcache eller eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP-moduler har blitt installert, men de listes fortsatt som fraværende?",
    "Please ask your server administrator to restart the web server." : "Be server-administratoren om å starte web-serveren på nytt.",
    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 kreves",
    "Please upgrade your database version" : "Vennligst oppgrader versjonen av databasen din",
    "Error occurred while checking PostgreSQL version" : "Det oppstod en feil ved sjekking av PostgreSQL-versjon",
    "Please make sure you have PostgreSQL >= 9 or check the logs for more information about the error" : "Sjekk at du har PostgreSQL >= 9 eller sjekk loggene for mer informasjon om feilen",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Endre tillatelsene til 0770 slik at mappen ikke kan listes av andre brukere.",
    "Data directory (%s) is readable by other users" : "Data-mappen (%s) kan leses av andre brukere",
    "Data directory (%s) is invalid" : "Data-mappe (%s) er ugyldig",
    "Please check that the data directory contains a file \".ocdata\" in its root." : "Sjekk at det ligger en fil \".ocdata\" i roten av data-mappen.",
    "Could not obtain lock type %d on \"%s\"." : "Klarte ikke å låse med type %d på \"%s\"."
},
"nplurals=2; plural=(n != 1);");

==> owncloud_8.1.12.orig.tar.gz: owncloud/lib/l10n/nb_NO.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Kan ikke skrive i \"config\"-mappen!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Dette kan vanligvis ordnes ved å gi web-serveren skrivetilgang til config-mappen",
    "See %s" : "Se %s",
    "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "Dette kan vanligvis ordnes ved %så gi web-serveren skrivetilgang til config-mappen%s.",
    "Sample configuration detected" : "Eksempelkonfigurasjon oppdaget",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Det ble oppdaget at eksempelkonfigurasjonen er blitt kopiert. Dette kan ødelegge installasjonen din og støttes ikke. Les dokumentasjonen før du gjør endringer i config.php",
    "PHP %s or higher is required." : "PHP %s eller nyere kreves.",
    "PHP with a version lower than %s is required." : "PHP med en versjon lavere enn %s kreves.",
    "Following databases are supported: %s" : "Følgende databaser støttes: %s",
    "The command line tool %s could not be found" : "Kommandolinjeverktøyet %s ble ikke funnet",
    "The library %s is not available." : "Biblioteket %s er ikke tilgjengelig.",
    "Library %s with a version higher than %s is required - available version %s." : "Bibliotek %s med en versjon høyere enn %s kreves - tilgjengelig versjon %s.",
    "Library %s with a version lower than %s is required - available version %s." : "Bibliotek %s med en versjon lavere nn %s kreves - tilgjengelig version %s.",
    "Following platforms are supported: %s" : "Følgende plattformer støttes: %s",
    "ownCloud %s or higher is required." : "ownCloud %s eller høyere kreves.",
    "ownCloud with a version lower than %s is required." : "ownCloud med en versjon lavere enn %s kreves.",
    "Help" : "Hjelp",
    "Personal" : "Personlig",
    "Users" : "Brukere",
    "Admin" : "Admin",
    "Recommended" : "Anbefalt",
    "App \"%s\" cannot be installed because it is not compatible with this version of ownCloud." : "App \"%s\" kan ikke installeres fordi den ikke er kompatibel med denne versjonen av ownCloud.",
    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "App \"%s\" kan ikke installeres fordi følgende avhengigheter ikke er tilfredsstilt: %s",
    "No app name specified" : "Intet app-navn spesifisert",
    "Unknown filetype" : "Ukjent filtype",
    "Invalid image" : "Ugyldig bilde",
    "today" : "i dag",
    "yesterday" : "i går",
    "_%n day ago_::_%n days ago_" : ["%n dag siden","%n dager siden"],
    "last month" : "forrige måned",
    "_%n month ago_::_%n months ago_" : ["for %n måned siden","for %n måneder siden"],
    "last year" : "forrige år",
    "_%n year ago_::_%n years ago_" : ["%n år siden","%n år siden"],
    "_%n hour ago_::_%n hours ago_" : ["for %n time siden","for %n timer siden"],
    "_%n minute ago_::_%n minutes ago_" : ["for %n minutt siden","for %n minutter siden"],
    "seconds ago" : "for få sekunder siden",
    "web services under your control" : "webtjenester som du kontrollerer",
    "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Modul med id: %s eksisterer ikke. Aktiver den i app-innstillingene eller kontakt en administrator.",
    "Empty filename is not allowed" : "Tomt filnavn er ikke tillatt",
    "Dot files are not allowed" : "Punktum-filer er ikke tillatt",
    "4-byte characters are not supported in file names" : "4-byte tegn er ikke tillatt i filnavn",
    "File name is a reserved word" : "Filnavnet er et reservert ord",
    "File name contains at least one invalid character" : "Filnavnet inneholder minst ett ulovlig tegn",
    "File name is too long" : "Filnavnet er for langt",
    "File is currently busy, please try again later" : "Filen er opptatt for øyeblikket, prøv igjen senere",
    "Can't read file" : "Kan ikke lese fil",
    "App directory already exists" : "App-mappe finnes allerede",
    "Can't create app folder. Please fix permissions. %s" : "Kan ikke opprette app-mappe.  Vennligst ordne opp i tillatelser. %s",
    "No source specified when installing app" : "Ingen kilde spesifisert ved installering av app",
    "No href specified when installing app from http" : "Ingen href spesifisert ved installering av app fra http",
    "No path specified when installing app from local file" : "Ingen sti spesifisert ved installering av app fra lokal fil",
    "Archives of type %s are not supported" : "Arkiver av type %s støttes ikke",
    "Failed to open archive when installing app" : "Klarte ikke å åpne arkiv ved installering av app",
    "App does not provide an info.xml file" : "App-en inneholder ikke filen info.xml",
    "App can't be installed because of not allowed code in the App" : "App kan ikke installeres på grunn av ulovlig kode i appen.",
    "App can't be installed because it is not compatible with this version of ownCloud" : "App kan ikke installeres fordi den ikke er kompatibel med denne versjonen av ownCloud",
    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "App kan ikke installeres fordi den inneholder tag <shipped>true</shipped> som ikke er tillatt for apper som ikke leveres med systemet",
    "App can't be installed because the version in info.xml/version is not the same as the version reported from the app store" : "App kan ikke installeres fordi versjonen i info.xml/version ikke er den samme som versjonen som rapporteres fra app-butikken",
    "Application is not enabled" : "Applikasjon er ikke påslått",
    "Authentication error" : "Autentikasjonsfeil",
    "Token expired. Please reload page." : "Symbol utløpt. Vennligst last inn siden på nytt.",
    "Unknown user" : "Ukjent bruker",
    "%s enter the database username." : "%s legg inn brukernavn for databasen.",
    "%s enter the database name." : "%s legg inn navnet på databasen.",
    "%s you may not use dots in the database name" : "%s du kan ikke bruke punktum i databasenavnet",
    "MS SQL username and/or password not valid: %s" : "MS SQL-brukernavn og/eller passord ikke gyldig: %s",
    "You need to enter either an existing account or the administrator." : "Du må legge inn enten en eksisterende konto eller administratoren.",
    "MySQL/MariaDB username and/or password not valid" : "MySQL/MariaDB-brukernavn og/eller -passord ikke gyldig",
    "DB Error: \"%s\"" : "Databasefeil: \"%s\"",
    "Offending command was: \"%s\"" : "Kommandoen som feilet: \"%s\"",
    "MySQL/MariaDB user '%s'@'localhost' exists already." : "MySQL/MariaDB-bruker '%s'@'localhost' finnes allerede.",
    "Drop this user from MySQL/MariaDB" : "Fjern denne brukeren fra MySQL/MariaDB",
    "MySQL/MariaDB user '%s'@'%%' already exists" : "MySQL/MariaDB-bruker '%s'@'%%' finnes allerede",
    "Drop this user from MySQL/MariaDB." : "Fjern denne brukeren fra MySQL/MariaDB.",
    "Oracle connection could not be established" : "Klarte ikke å etablere forbindelse til Oracle",
    "Oracle username and/or password not valid" : "Oracle-brukernavn og/eller passord er ikke gyldig",
    "Offending command was: \"%s\", name: %s, password: %s" : "Kommando som feilet: \"%s\", navn: %s, passord: %s",
    "PostgreSQL username and/or password not valid" : "PostgreSQL-brukernavn og/eller passord er ikke gyldig",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X støttes ikke og %s vil ikke fungere korrekt på denne plattformen. Bruk på egen risiko!",
    "For the best results, please consider using a GNU/Linux server instead." : "For beste resultat, vurder å bruke en GNU/Linux-server i stedet.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Det ser ut for at %s-instansen kjører i et 32-bit PHP-miljø med open_basedir konfigurert i php.ini. Dette vil føre til problemer med filer over 4 GB og frarådes på det sterkeste.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Vennligst fjern innstillingen open_basedir i php.ini eller bytt til 64-bit PHP.",
    "Set an admin username." : "Sett et admin-brukernavn.",
    "Set an admin password." : "Sett et admin-passord.",
    "Can't create or write into the data directory %s" : "Kan ikke opprette eller skrive i datamappen %s",
    "Invalid Federated Cloud ID" : "Ugyldig ID for sammenknyttet sky",
    "%s shared »%s« with you" : "%s delte »%s« med deg",
    "%s via %s" : "%s via %s",
    "Sharing %s failed, because the backend does not allow shares from type %i" : "Deling av %s feilet, fordi serveren ikke tillater delinger fra type %i",
    "Sharing %s failed, because the file does not exist" : "Deling av %s feilet, fordi filen ikke eksisterer",
    "You are not allowed to share %s" : "Du har ikke lov til å dele %s",
    "Sharing %s failed, because the user %s is the item owner" : "Deling av %s feilet, fordi brukeren %s er eier av elementet",
    "Sharing %s failed, because the user %s does not exist" : "Deling av %s feilet, fordi brukeren %s ikke finnes",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Deling av %s feilet, fordi brukeren %s ikke er medlem av noen grupper som %s er medlem av",
    "Sharing %s failed, because this item is already shared with %s" : "Deling av %s feilet, fordi dette elementet allerede er delt med %s",
    "Sharing %s failed, because the group %s does not exist" : "Deling av %s feilet, fordi gruppen %s ikke finnes",
    "Sharing %s failed, because %s is not a member of the group %s" : "Deling av %s feilet, fordi %s ikke er medlem av gruppen %s",
    "You need to provide a password to create a public link, only protected links are allowed" : "Du må oppgi et passord for å lage en offentlig lenke. Bare beskyttede lenker er tillatt",
    "Sharing %s failed, because sharing with links is not allowed" : "Deling av %s feilet, fordi deling med lenker ikke er tillatt",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Deling %s feilet, fant ikke %s, kanskje servern er utilgjengelig for øyeblikket.",
    "Share type %s is not valid for %s" : "Delingstype %s er ikke gyldig for %s",
    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "Setting av tillatelser for %s feilet, fordi tillatelsene gikk ut over tillatelsene som er gitt til %s",
    "Setting permissions for %s failed, because the item was not found" : "Setting av tillatelser for %s feilet, fordi elementet ikke ble funnet",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Kan ikke sette utøpsdato. Delinger kan ikke utløpe senere enn %s etter at de har blitt delt",
    "Cannot set expiration date. Expiration date is in the past" : "Kan ikke sette utløpsdato. Utløpsdato er tilbake i tid",
    "Cannot clear expiration date. Shares are required to have an expiration date." : "Kan ikke fjerne utløpsdato. Delinger må ha en utløpsdato.",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Delings-server %s må implementere grensesnittet OCP\\Share_Backend",
    "Sharing backend %s not found" : "Delings-server %s ikke funnet",
    "Sharing backend for %s not found" : "Delings-server for %s ikke funnet",
    "Sharing %s failed, because the user %s is the original sharer" : "Deling av %s feilet, fordi brukeren %s er den opprinnelige eieren",
    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Deling av %s feilet, fordi tillatelsene går utover tillatelsene som er gitt til %s",
    "Sharing %s failed, because resharing is not allowed" : "Deling av %s feilet, fordi videre-deling ikke er tillatt",
    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Deling av %s feilet, fordi delings-serveren for %s ikke kunne finne kilden",
    "Sharing %s failed, because the file could not be found in the file cache" : "Deling av %s feilet, fordi filen ikke ble funnet i fil-mellomlageret",
    "Could not find category \"%s\"" : "Kunne ikke finne kategori \"%s\"",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-\"" : "Bare disse tegnene tillates i et brukernavn: \"a-z\", \"A-Z\", \"0-9\" og \"_.@-\"",
    "A valid username must be provided" : "Oppgi et gyldig brukernavn",
    "A valid password must be provided" : "Oppgi et gyldig passord",
    "The username is already being used" : "Brukernavnet er allerede i bruk",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Ingen databasedrivere (sqlite, mysql, or postgresql) installert.",
    "Microsoft Windows Platform is not supported" : "Microsoft Windows-plattform støttes ikke",
    "Running ownCloud Server on the Microsoft Windows platform is not supported. We suggest you use a Linux server in a virtual machine if you have no option for migrating the server itself. Find Linux packages as well as easy to deploy virtual machine images on <a href=\"%s\">%s</a>. For migrating existing installations to Linux you can find some tips and a migration script in <a href=\"%s\">our documentation</a>." : "Kjøring av ownCloud Server på Microsoft Windows-plattformen er ikke støttet. Vi foreslår at du bruker en Linux-server i en virtuell maskin hvis du ikke har mulighet til å migrere selve serveren. Du finner Linux-pakker og lett installerbare avbildninger for virtuelle maskiner på <a href=\"%s\">%s</a>. For å migrere eksisterende installasjoner til Linux finner du tips og et migrerings-script i <a href=\"%s\">dokumentasjonen vår</a>.",
    "Cannot write into \"config\" directory" : "Kan ikke skrive i \"config\"-mappen",
    "Cannot write into \"apps\" directory" : "Kan ikke skrive i \"apps\"-mappen",
    "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Dette kan vanligvis ordnes ved %så gi web-serveren skrivetilgang til apps-mappen%s eller ved å deaktivere app-butikken i config-filen.",
    "Cannot create \"data\" directory (%s)" : "Kan ikke opprette \"data\"-mappen (%s)",
    "This can usually be fixed by <a href=\"%s\" target=\"_blank\">giving the webserver write access to the root directory</a>." : "Dette kan vanligvis ordnes ved <a href=\"%s\" target=\"_blank\">gi web-serveren skrivetilgang til rotmappen</a>.",
    "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Tillatelser kan vanligvis ordnes ved %så gi web-serveren skrivetilgang til rotmappen%s.",
    "Setting locale to %s failed" : "Setting av nasjonale innstillinger til %s feilet.",
    "Please install one of these locales on your system and restart your webserver." : "Vennligst installer en av disse nasjonale innstillingene på systemet ditt og start webserveren på nytt.",
    "Please ask your server administrator to install the module." : "Be server-administratoren om å installere modulen.",
    "PHP module %s not installed." : "PHP-modul %s er ikke installert.",
    "PHP setting \"%s\" is not set to \"%s\"." : "PHP-innstilling \"%s\" er ikke satt til \"%s\".",
    "Adjusting this setting in php.ini will make ownCloud run again" : "Endring av denne innstillingen i php.ini vil få ownCloud til å kjøre igjen.",
    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload er satt til \"%s\" i stedet for den forventede verdien \"0\"",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Sett <code>mbstring.func_overload</code> til <code>0</code> in php.ini for å fikse dette problemet",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Det ser ut for at PHP er satt opp til å fjerne innebygde doc blocks. Dette gjør at flere av kjerneapplikasjonene blir utilgjengelige.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Dette forårsakes sannsynligvis av en bufrer/akselerator, som f.eks. Zend OPcache eller eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP-moduler har blitt installert, men de listes fortsatt som fraværende?",
    "Please ask your server administrator to restart the web server." : "Be server-administratoren om å starte web-serveren på nytt.",
    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 kreves",
    "Please upgrade your database version" : "Vennligst oppgrader versjonen av databasen din",
    "Error occurred while checking PostgreSQL version" : "Det oppstod en feil ved sjekking av PostgreSQL-versjon",
    "Please make sure you have PostgreSQL >= 9 or check the logs for more information about the error" : "Sjekk at du har PostgreSQL >= 9 eller sjekk loggene for mer informasjon om feilen",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Endre tillatelsene til 0770 slik at mappen ikke kan listes av andre brukere.",
    "Data directory (%s) is readable by other users" : "Data-mappen (%s) kan leses av andre brukere",
    "Data directory (%s) must be an absolute path" : "Datamappen (%s) må være en absolutt sti",
    "Check the value of \"datadirectory\" in your configuration" : "Sjekk verdien for \"datadirectory\" i konfigurasjonen din",
    "Data directory (%s) is invalid" : "Data-mappe (%s) er ugyldig",
    "Please check that the data directory contains a file \".ocdata\" in its root." : "Sjekk at det ligger en fil \".ocdata\" i roten av data-mappen.",
    "Could not obtain lock type %d on \"%s\"." : "Klarte ikke å låse med type %d på \"%s\"."
},
"nplurals=2; plural=(n != 1);");
